---
name: Bug report
about: Create a report to help us improve
title: "A bug was found in coffea.XYZ"
labels: 'bug'
assignees: ''

---

**Describe the bug**
A clear and concise description of what the bug is.

**To Reproduce**
Steps to reproduce the behavior:
1. write analysis operation '...'
2. if applicable: run on scaleout platform '...' (local multiprocessing, spark, ...)
3. if applicable: make plots like '...'
4. See error

**Expected behavior**
A clear and concise description of what you expected to happen.

**Output**
If applicable, add output, screenshots, or plots to help explain your problem.

**Desktop (please complete the following information):**
 - OS: [e.g. linux, osx,...]
 - Version [e.g. 22]

**Additional context**
Add any other context about the problem here.
